@@ -6,7 +6,7 @@
  * An encapsulation layer for msghdr structures, cause that's the worst
  * system-level API I have ever seen.
  *
- * $Id: msghdr.c,v 1.11 2002/09/16 21:02:03 dougk Exp $
+ * $Id: msghdr.c,v 1.14 2002/10/11 02:31:51 dougk Exp $
  */
  
 #include "../config.h"
@@ -20,6 +20,7 @@
 #include <sys/types.h>
 #include <sys/uio.h>
 #include <sys/socket.h>
+#include <syslog.h>
 
 /*
  * 1: Data structure comments.
@@ -71,6 +72,9 @@ struct message {
     size_t              recv_len;/*amount of data not yet read. */
 };
 
+#ifdef LO_CMSG_DEF
+#define CMSG_LEN(len) (_CMSG_DATA_ALIGN (sizeof (struct cmsghdr)) + (len))
+#endif
 #define cmsglen CMSG_LEN(sizeof(int))
 #define MIN(a,b) ((a) < (b) ? (a) : (b))
 
@@ -238,7 +242,7 @@ void msg_addString(message_t *msg, const char *s) {
 void msg_setFd(message_t *msg, int fd)
 {
     if (msg->cmsg != NULL && msg->cmsg->cmsg_len != 0) {
-        fputs("Error.  Ran out of ancillary data space.",stderr);
+        syslog(LOG_ERR,"msg_setFD ran out of ancillary data space.");
         abort();
     }
     if (msg->cmsg == NULL)
@@ -337,7 +341,7 @@ int msg_getFd  (message_t *msg)
     if (msg->cmsg == NULL || msg->cmsg->cmsg_len != cmsglen
             || msg->cmsg->cmsg_level != SOL_SOCKET
             || msg->cmsg->cmsg_type  != SCM_RIGHTS) {
-        fputs("Error.  No FD in message.", stderr);
+        syslog(LOG_ERR,"msg_getFd: No FD in message.");
         return -1;
     }
 
