@@ -6,7 +6,7 @@
  * Provides the client half of the process.  Should be considered
  * untrusted by the privman server.
  *
- * $Id: priv_client.cc,v 1.22 2002/09/17 20:28:33 dougk Exp $
+ * $Id: priv_client.cc,v 1.24 2002/10/10 19:17:14 dougk Exp $
  */
 
 #include "../config.h"
@@ -22,6 +22,7 @@
 #include <errno.h>
 #include <assert.h>
 #include <sys/wait.h>
+#include <syslog.h>
 
 #include "privman.h"
 #include "msghdr.h"
@@ -89,7 +90,8 @@ static void handleConvert(message_t *msg)
     }
 
     rc = ((struct pam_conv*)pam_types[PAM_CONV])->conv(num_msg,
-            (const struct pam_message **)messages, /* C const fun cast */
+                /* C const fun cast */
+            (PAM_CONV_FUNC_CONST struct pam_message **)messages,
             &resp, ((struct pam_conv*)pam_types[PAM_CONV])->appdata_ptr);
 
 
