@@ -6,7 +6,7 @@
  * Header file for the implimentation bits of privman.  Things common
  * between the server and the client halves.
  *
- * $Id: priv_impl.h,v 1.12 2002/08/27 23:16:09 dougk Exp $
+ * $Id: priv_impl.h,v 1.13 2002/09/14 06:57:50 dougk Exp $
  */
 
 
@@ -83,10 +83,7 @@ void msg_initResponce(message_t *msg, int rc) {
 static __inline__ void boom(const char *where) __attribute((__noreturn__));
 static __inline__ void boom(const char *where)
 {
-#if 0
-    syslog(LOG_INFO, "%s: %m", where);
-#endif
-    perror(where);
+    syslog(LOG_ERR, "%s: %m", where);
     /* Only one of the two processes should exit().  The other should
      * _exit().  To allow atexit() et. all to work for the client
      * processes, the parent will use _exit().
