@@ -6,7 +6,7 @@
  * Provides the server half of the process.  This half retains priviledge
  * and should be nei-invulnerable.
  *
- * $Id: privman.cc,v 1.34 2002/09/16 20:06:14 dougk Exp $
+ * $Id: privman.cc,v 1.37 2002/10/10 19:17:14 dougk Exp $
  */
 #include "../config.h"
 #include <stdio.h>
@@ -24,6 +24,12 @@
 #include <netinet/in.h>
 #include <sys/wait.h>
 #include <syslog.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#ifdef HAVE_SYS_BYTEORDER_H
+#include <sys/byteorder.h>
+#endif
 
 #include <map>
 
@@ -66,7 +72,8 @@ std::map< enum commands, void(*)(message_t*) > function_map;
 #endif
 
 static int convert_punt(int num_msg,
-        const struct pam_message **messages, struct pam_response **resp,
+        PAM_CONV_FUNC_CONST struct pam_message **messages,
+        struct pam_response **resp,
         void * UNUSED(app_ptr))
 {
     message_t                  *msg = msg_new();
@@ -386,7 +393,7 @@ static void pamGetItem(message_t *msg)
 
     assert(type != PAM_CONV);
 
-    rc = pam_get_item(pamh, type, (const void **)(&item));
+    rc = pam_get_item(pamh, type, (PAM_GET_ITEM_CONST void **)(&item));
 
     msg_clear(msg);
 
@@ -740,7 +747,9 @@ PAM_SIMPLE_HANDLER(pamSetcred,          pam_setcred)
 PAM_SIMPLE_HANDLER(pamOpenSession,      pam_open_session)
 PAM_SIMPLE_HANDLER(pamCloseSession,     pam_close_session)
 PAM_SIMPLE_HANDLER(pamChauthtok,        pam_chauthtok)
+#ifdef HAVE_PAM_FAIL_DELAY
 PAM_SIMPLE_HANDLER(pamFailDelay,     (int(*)(pam_handle_t*,int))pam_fail_delay)
+#endif
 
 void privman_serv_init(void)
 {
@@ -758,7 +767,9 @@ void privman_serv_init(void)
     function_map[ CMD_PAM_OPEN_SESSION  ] = pamOpenSession;
     function_map[ CMD_PAM_CLOSE_SESSION ] = pamCloseSession;
     function_map[ CMD_PAM_CHAUTHTOK     ] = pamChauthtok;
+#ifdef HAVE_PAM_FAIL_DELAY
     function_map[ CMD_PAM_FAIL_DELAY    ] = pamFailDelay;
+#endif
 
     function_map[ CMD_FORK              ] = forkProcess;
     function_map[ CMD_EXIT              ] = exitServer;
