@@ -8,7 +8,7 @@
  * connection, which ought to be "test passed."  It only listens
  * for one connection, and quits upon seeing ^D
  *
- * $Id: myecho.c,v 1.10 2002/09/16 20:13:17 dougk Exp $
+ * $Id: myecho.c,v 1.11 2002/10/11 21:51:16 dougk Exp $
  */
 
 #include "../config.h"
@@ -25,6 +25,10 @@
 
 #include <netinet/in.h>
 
+#ifdef HAVE_SYS_BYTEORDER_H
+#include <sys/byteorder.h>
+#endif
+
 int getPort(char *port) {
     /* port = "80"
      * port = "web"
