@@ -9,7 +9,7 @@
  * properly if it doesn't have the correct permission.  It only listens
  * for one connection, and quits upon seeing ^D
  *
- * $Id: myecho2.c,v 1.6 2002/09/16 20:13:17 dougk Exp $
+ * $Id: myecho2.c,v 1.7 2002/10/11 21:51:16 dougk Exp $
  */
 
 #include "../config.h"
@@ -26,6 +26,9 @@
 #include <netdb.h>
 
 #include <netinet/in.h>
+#ifdef HAVE_SYS_BYTEORDER_H
+#include <sys/byteorder.h>
+#endif
 
 int getPort(char *port) {
     /* port = "80"
